@@ -56,7 +56,7 @@ describe 'nova::api' do
       it { is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_ensure('absent')}
 
       it 'configures various stuff' do
-        is_expected.to contain_nova_config('DEFAULT/api_paste_config').with('value' => 'api-paste.ini')
+        is_expected.to contain_nova_config('wsgi/api_paste_config').with('value' => 'api-paste.ini')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with('value' => '0.0.0.0')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8774')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '0.0.0.0')
@@ -66,11 +66,7 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '5')
         is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'nova')
         is_expected.to contain_nova_config('DEFAULT/fping_path').with('value' => '/usr/sbin/fping')
-        is_expected.to contain_nova_config('DEFAULT/secure_proxy_ssl_header').with('value' => '<SERVICE DEFAULT>')
-      end
-
-      it 'do not configure v3 api' do
-        is_expected.to contain_nova_config('osapi_v3/enabled').with('value' => false)
+        is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
       end
 
       it 'unconfigures neutron_metadata proxy' do
@@ -100,9 +96,8 @@ describe 'nova::api' do
           :osapi_compute_workers                => 1,
           :metadata_workers                     => 2,
           :default_floating_pool                => 'public',
-          :osapi_v3                             => true,
-          :pci_alias                            => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]",
-          :secure_proxy_ssl_header              => "HTTP-X-Forwarded-Proto"
+          :enable_proxy_headers_parsing         => true,
+          :pci_alias                            => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]"
         })
       end
 
@@ -146,13 +141,9 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '1')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '2')
         is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'public')
-        is_expected.to contain_nova_config('DEFAULT/secure_proxy_ssl_header').with('value' => 'HTTP-X-Forwarded-Proto')
         is_expected.to contain_nova_config('neutron/service_metadata_proxy').with('value' => true)
         is_expected.to contain_nova_config('neutron/metadata_proxy_shared_secret').with('value' => 'secrete')
-      end
-
-      it 'configure nova api v3' do
-        is_expected.to contain_nova_config('osapi_v3/enabled').with('value' => true)
+        is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => true)
       end
 
       it 'configures nova pci_alias entries' do
@@ -323,28 +314,6 @@ describe 'nova::api' do
       end
     end
 
-    context 'when enabled_apis is not an array' do
-      before do
-        params.merge!({
-          :service_name => 'httpd',
-          :enabled_apis => 'osapi_compute' })
-      end
-
-      let :pre_condition do
-        "include ::apache
-         include ::nova"
-      end
-
-      it 'disable nova API service' do
-        is_expected.to contain_service('nova-api').with(
-          :ensure     => 'stopped',
-          :name       => platform_params[:nova_api_service],
-          :enable     => false,
-          :tag        => 'nova-service',
-        )
-      end
-    end
-
     context 'when service_name is not valid' do
       before do
         params.merge!({ :service_name   => 'foobar' })
