@@ -43,51 +43,39 @@ describe 'nova' do
 
       it 'configures rabbit' do
         is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('rabbit')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('localhost')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('guest').with_secret(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('5672')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('/')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('0')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('2')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures various things' do
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova')
         is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value(platform_params[:lock_path])
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
-        is_expected.to contain_nova_config('DEFAULT/notification_driver').with_ensure('absent')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
         is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/os_region_name').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_userid').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_host').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_port').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_password').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_virtual_host').with_ensure('absent')
         is_expected.to contain_nova_config('cinder/os_region_name').with_ensure('absent')
         is_expected.to contain_nova_config('cinder/catalog_info').with('value' => 'volumev2:cinderv2:publicURL')
       end
 
-      it 'does not install utilities' do
-        is_expected.to_not contain_class('nova::utilities')
-      end
-
     end
 
     context 'with overridden parameters' do
 
       let :params do
-        { :verbose                            => true,
-          :debug                              => true,
+        { :debug                              => true,
           :log_dir                            => '/var/log/nova2',
           :image_service                      => 'nova.image.local.LocalImageService',
+          :rpc_backend                        => 'rabbit',
           :rabbit_host                        => 'rabbit',
           :rabbit_userid                      => 'rabbit_user',
           :rabbit_port                        => '5673',
           :rabbit_password                    => 'password',
-          :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :lock_path                          => '/var/locky/path',
@@ -96,7 +84,7 @@ describe 'nova' do
           :auth_strategy                      => 'foo',
           :ensure_package                     => '2012.1.1-15.el6',
           :memcached_servers                  => ['memcached01:11211', 'memcached02:11211'],
-          :install_utilities                  => true,
+          :host                               => 'test-001.example.org',
           :notification_driver                => 'ceilometer.compute.nova_notifier',
           :notification_topics                => 'openstack',
           :notify_api_faults                  => true,
@@ -142,7 +130,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('rabbit_user')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('/')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
       end
@@ -151,6 +139,10 @@ describe 'nova' do
         is_expected.to contain_nova_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
       end
 
+      it 'configures host' do
+        is_expected.to contain_nova_config('DEFAULT/host').with_value('test-001.example.org')
+      end
+
       it 'configures upgrade_levels' do
         is_expected.to contain_nova_config('upgrade_levels/cells').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/cert').with_value('1.0.0')
@@ -167,32 +159,22 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova2')
         is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value('/var/locky/path')
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('120')
-        is_expected.to contain_nova_config('DEFAULT/notification_driver').with_value('ceilometer.compute.nova_notifier')
-        is_expected.to contain_nova_config('DEFAULT/notification_topics').with_value('openstack')
+        is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
+        is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('DEFAULT/notify_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('true')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
-        is_expected.to contain_nova_config('DEFAULT/os_region_name').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_userid').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_host').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_port').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_password').with_ensure('absent')
-        is_expected.to contain_nova_config('DEFAULT/rabbit_virtual_host').with_ensure('absent')
       end
 
       context 'with multiple notification_driver' do
         before { params.merge!( :notification_driver => ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']) }
 
-        it { is_expected.to contain_nova_config('DEFAULT/notification_driver').with_value(
+        it { is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value(
           'ceilometer.compute.nova_notifier,nova.openstack.common.notifier.rpc_notifier'
         ) }
       end
 
-      it 'installs utilities' do
-        is_expected.to contain_class('nova::utilities')
-      end
-
     end
 
     context 'with wrong notify_on_state_change parameter' do
@@ -221,17 +203,18 @@ describe 'nova' do
       end
 
       it 'configures rabbit' do
-        is_expected.to_not contain_nova_config('oslo_messaging_rabbit/rabbit_host')
-        is_expected.to_not contain_nova_config('oslo_messaging_rabbit/rabbit_port')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673,rabbit2:5674')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('1.0')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(false)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_ensure('absent')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -241,13 +224,13 @@ describe 'nova' do
       end
 
       it 'configures rabbit' do
-        is_expected.to_not contain_nova_config('oslo_messaging_rabbit/rabbit_host')
-        is_expected.to_not contain_nova_config('oslo_messaging_rabbit/rabbit_port')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('1.0')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(false)
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -263,7 +246,7 @@ describe 'nova' do
 
     context 'with rabbit_ha_queues set to true' do
       let :params do
-        { :rabbit_ha_queues => 'true' }
+        { :rabbit_ha_queues => true }
       end
 
       it 'configures rabbit' do
@@ -285,27 +268,27 @@ describe 'nova' do
     context 'with amqp_durable_queues parameter' do
       let :params do
         { :rabbit_hosts => ['rabbit:5673'],
-          :amqp_durable_queues => 'true' }
+          :amqp_durable_queues => true }
       end
 
       it 'configures rabbit' do
-        is_expected.to_not contain_nova_config('oslo_messaging_rabbit/rabbit_host')
-        is_expected.to_not contain_nova_config('oslo_messaging_rabbit/rabbit_port')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_ensure('absent')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
       end
     end
 
     context 'with rabbit ssl enabled with kombu' do
       let :params do
         { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => 'true',
+          :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
@@ -324,33 +307,15 @@ describe 'nova' do
     context 'with rabbit ssl enabled without kombu' do
       let :params do
         { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => 'true', }
+          :rabbit_use_ssl     => true, }
       end
 
       it 'configures rabbit' do
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-      end
-    end
-
-    context 'with rabbit ssl disabled' do
-      let :params do
-        {
-          :rabbit_password    => 'pass',
-          :rabbit_use_ssl     => false,
-          :kombu_ssl_version  => 'TLSv1',
-        }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('false')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_ensure('absent')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_ensure('absent')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -359,7 +324,58 @@ describe 'nova' do
         { :rpc_backend => 'nova.openstack.common.rpc.impl_kombu' }
       end
 
-      it { is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('nova.openstack.common.rpc.impl_kombu') }
+      it { is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('rabbit') }
+    end
+
+    context 'with amqp rpc_backend default parameters' do
+      let :params do
+        { :rpc_backend => 'amqp' }
+      end
+
+      it 'configures amqp' do
+        is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('amqp')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')
+      end
+    end
+
+    context 'with amqp rpc_backend overriden parameters' do
+      let :params do
+        { :rpc_backend        => 'amqp',
+          :amqp_idle_timeout  => '60',
+          :amqp_trace         => true,
+          :amqp_ssl_ca_file   => '/etc/ca.cert',
+          :amqp_ssl_cert_file => '/etc/certfile',
+          :amqp_ssl_key_file  => '/etc/key',
+          :amqp_username      => 'amqp_user',
+          :amqp_password      => 'password',
+        }
+      end
+
+      it 'configures amqp overide' do
+        is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('amqp')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/idle_timeout').with_value('60')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/trace').with_value('true')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_ca_file').with_value('/etc/ca.cert')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_cert_file').with_value('/etc/certfile')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_file').with_value('/etc/key')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/username').with_value('amqp_user')
+        is_expected.to contain_nova_config('oslo_messaging_amqp/password').with_value('password')
+      end
     end
 
     context 'with ssh public key' do
